#!/bin/sh -e

# Check if in right directory and/or build is run
if [ ! -e fpga.bit ]
then
	echo "File 'fpga.bit' not found."
	exit 1
fi

# For future expansion
case "$FPGA_FAMILY" in
	xc7z010)
		MACHINE=tdkz10
		PART=xc7z010clg400-1
		;;
	xc7z020)
		MACHINE=tdkz20
		PART=xc7z020clg400-1
		;;
	xc7z007)
		MACHINE=tdkz07
		PART=xc7z007sclg400-1
		;;
	xc7z012)
		MACHINE=tdkz12
		PART=xc7z012sclg400-1
		;;
	*)
		echo "Environment variable FPGA_FAMILY=$FPGA_FAMILY is not valid"
		echo "Valid are: xc7z010, xc7z020, xc7z007 xc7z012"
		exit 1
		;;
esac

if [ ! -e "${PART}.xsa" ]
then
	echo "File '${PART}.xsa' not found."
	exit 1
fi

PACKAGE_NAME="fpga-image-${MACHINE}-reference"
PACKAGE2_NAME="fpga-hardware-${MACHINE}-reference"

VERSION=`git rev-list HEAD | wc -l`+`git rev-parse --short HEAD`

xz -9 < fpga.bit > ${PACKAGE_NAME}-${VERSION}.bit.xz
xz -9 < "${PART}.xsa" > ${PACKAGE2_NAME}-${VERSION}.xsa.xz
